#!/bin/sh

#
# Starts ( MvWebService ) running as a daemon.
#
#
# Copyright (c) 1999, 2000 Lexmark International, Inc.
# All Rights Reserved.
#
VERSION="pebbles_pebg6_pebblesibm"
#

#
# DEBUG Variable.
#   No Debug = 0
#   Debug = 1
#
#

#
# Added /usr/bin and /bin to PATH for HP
PATH=$PATH:/usr/bin:/bin
export PATH
#
#

if [ -f /usr/mv_pro/etc/mv_server_user ]; then
   MVUSER="`cat /usr/mv_pro/etc/mv_server_user | grep web_server_user | awk -F"=" '{print $2}'`"
   PORT="`cat /usr/mv_pro/etc/mv_server_user | grep web_server_ports | awk -F"=" '{print $2}'`"
else
   grep -q 'port="80"' /usr/mv_pro/mvweb/www/conf/server.xml
   if [ "$?" != "0" ];then
      PORT="tcp:9180"
   else
      PORT="tcp:80 and tcp:9180"
   fi
fi

WHOAMI=/usr/bin/whoami

# If this is a 1 System, we want to run this script without
# most echo's if running during system startup and shutdown
# so that the Start Up and Shutdown Screens look correctly.

dirname $0 | grep sbin 2>/dev/null 1>/dev/null
if [ "$?" = "1" ]; then
   HPstrstp=1
else
   HPstrstp=0
fi



# If this is a SCO Systems Build, we need to determine if we are
# running on a OpenServer or UnixWare Box.  The ulimit command needs
# to change depending on which system is currently running this script.

systype=`uname -a | (read p1 p2 p3 p4 p5 p6 p7 p8 p9; echo $p1 $p3)`
MAC=`echo $systype | awk '{print $1}'`


DEBUG="0"
RunMvWebService=""
set -- "$@"

while [ "$1" != "" ]
do
   case "$1" in
	   start_msg)
                echo "Start MvWebService subsystem"
                ;;

           stop_msg)
                echo "Stop MvWebService subsystem"
                ;;

           restart )
                 echo "Re-Starting MvWebService ...."
                 RunMvWebService="restart"
                 ;;

           start )
                 RunMvWebService="start"
                 echo
                 if [ "$HPstrstp" = "1" ]; then
                    echo "Starting MvWebService ...."
                 fi
                 ;;

           stop )
                 RunMvWebService="stop"
                 if [ "$HPstrstp" = "1" ]; then
                 echo
                 echo "Stop MvWebService Subsystem...."
                 fi
                 ;;
      
            status )
                 RunMvWebService="status"
                 echo
                 ;;

           kill )
                 DEBUG="0"
                 RunMvWebService="kill"
                 echo
                 echo "Killing MvWebService Process ...."
                 ;;

            -d )
                 DEBUG="1"
                 echo
                 echo "MvWebService is running in Debug Mode"
                 ;;

           -v )
                  echo
                  echo "MvWebService Version is [ $VERSION ]."
                  echo
                  exit 1 ;;

           -V )
                  echo
                  echo "MvWebService Version is [ $VERSION ]."
                  echo
                  exit 1 ;;

	     * )
                 echo
                 echo "Usage: MvWebService { start|stop|restart|status }"
                 echo
                 exit 0
                 ;;

   esac
   
   shift 1
done


#

# Create a variable to store checkPIDFile return codes
CHKPIDRC=0

# Create a variable to store Java return codes
CHKGNRC=0

# Specifies the file containing the PID of the running MvWebService
pidfile=/var/spool/markvision/MvWebService.pid

#
# check PID file. Start new process if 0 returned.
#
#   Returns 0 if $pidfile contains the PID of the running MvWebService.
#   Returns 1 if $pidfile is not found, zero length, process not running.
#   Returns 2 if $pidfile contains PID, but process not running.
#

checkPIDFile ()
{
        if [ ! -s $pidfile ]
        then
           # PID file is not found, or zero length file, which
           # means that no MvWebService is currently running. It is
           # ok to start the new process

			  CHKPIDRC=1
			  return 1
        else
           # The file exists and has a non zero size
           # Read the process ID from the file
           lastPID=`cat $pidfile`

           # see if this is an MvWebService
if [ "$MAC" = "Darwin" ]; then
           ps auxww |grep ${lastPID} 2>/dev/null 1>/dev/null
else
           ps -p ${lastPID} 2>/dev/null 1>/dev/null
fi

           # check the error code, 0 indicates the process did not die
           if [ "$?" = "0" ]
           then
              # The process did not die -- must be a MvWebService since
              # it ignores all signals. It MvWebService.
              # echo "MvWebService running at $lastPID"

                         CHKPIDRC=0
                         return 0
           else
              # kill failed, the process must not be running, remove bad PID file.
              # echo "Process [${lastPID}] not running"
              rm -rf $pidfile 2>/dev/null 1>/dev/null

				  CHKPIDRC=2
                                  return 2
           fi
        fi
}

#
# Sets the necessary Java env vars for this script
# JAVABIN, JAVA_HOME, JVM_ARGS, CLASSPATH
#
setJavaVars ()
{
   
        JAVA_HOME=/usr/mvp_java

        TOMTARGET=org.apache.tomcat.startup.Main
 
        TOMDIR=/usr/mv_pro/mvweb/www

# This will set the CLASSPATH for MvWebService. 

        CLASSPATH=MvWebService.prog:/usr/mv_pro/mvweb/www/lib/tomcat.jar
 
        # Run findJava if java link not present (which will create the link)
        if [ ! -x $JAVA_HOME ];
        then
                /usr/mv_pro/bin/findJava
                RET=$?; 
                if [ $RET -ne 0 ]; then 
                   exit $RET;
                fi 
        fi

        # Set the Java VM flags (override w/ JVM_ARGS env var)
        if [ "$JVM_ARGS" = "" ];
        then

                # Set minimum VM size to 16MB and maximum to 64MB
                
                JVM_ARGS="-ms16m -mx256m"

                if [ "$DEBUG" = "1" ];
                then
                   echo ""
                   echo "Java Arguments =   '$JVM_ARGS'"
                fi
   
        fi
   
        # See which Runtime version is present
        
        if [ -f $JAVA_HOME/bin/jre ];
        then
                
                # JDK 1.1
           JAVABIN=$JAVA_HOME/bin/jre
   
        else

                # JDK 1.2
                # Make sure the file exists
           if [ -f $JAVA_HOME/bin/java ]; then
              JAVABIN=$JAVA_HOME/bin/java
           else
              echo " "
              echo "   We could not find a Java Runtime."
              echo " "
              echo "   Please make sure a Java Runtime is in your"
              echo "   path and run $0 again."
              exit 0;
           fi

        fi

        # Sets up the MvWebService Start Command
        StartCMD="$JAVABIN $JVM_ARGS -Dtomcat.home=/usr/mv_pro/mvweb/www -classpath $CLASSPATH $TOMTARGET start"

        # Sets up the MvWebService Stop Command
        StopCMD="$JAVABIN -Dtomcat.home=/usr/mv_pro/mvweb/www -classpath $CLASSPATH $TOMTARGET stop"

}

# Starts MvWebService - Java MUST be installed
startMvWebService ()
{
        # Initialize Java vars for this script
        setJavaVars
        
        if [ "$DEBUG" = "1" ];        
        then
           echo "Debug Mode -- We will not Ignore any Signals"
           echo "Bypassing the Ignore all Signals"
        else
           # Ignore all signals (trap each number separately for compatibility - SCOV)
           count=1;
           while [ $count -le 32 ];
           do
                result=`/bin/sh -c "trap '' $count 2>&1"` ; rc=$?
                if [ $rc -eq 0 -a "$result" = "" ] ; then
                   trap "" $count 2>/dev/null 1>/dev/null 
                fi
                count=`expr $count + 1`
           done
        fi


   # See if an instance is already running
  
        # Make sure the file exists
		  checkPIDFile
        
		  if [ "$CHKPIDRC" = "0" ]
        then
                
	        if [ "$HPstrstp" = "1" ]; then
                echo  "MarkVision MvWebService is already running."
                echo  "Process ID [${lastPID}] as User [ `$WHOAMI` ] on TCP Port [ $PORT ]."
                echo
                exit 1;
                fi
        
        else

           # PID file is not found, has zero length. It is OK to start the daemon
           
           # Up the ulimit if necessary (Platform specific)
               
                if [ "$DEBUG" = "1" ]; 
                then
                   echo "Running .... "
                   echo ulimit -Sn 1024
                fi
                

                ulimit -Sn 1024 

                # Start the daemon
           cd / 
           #-- Run the Java bytecode interpreter in the background,
           #-- making sure to close extraneous file descriptors so that
           #-- the new process doesn't inherit an open descriptor to
           #-- the package file during automated postinstall.
           if [ "$DEBUG" = "1" ];
           then  
              echo ""
              echo "Running MvWebService without Redirecting and closing"
              echo "file handlers" 
              echo "Running the following command:"
              echo "$StartCMD"
              echo
                       cd $TOMDIR
                       $StartCMD & 
		       CHKGNRC=$?
              
	      # Save the MvWebServicej Process ID to a file
              echo $! > $pidfile
           else
  			cd $TOMDIR
                        $StartCMD \
                        0</dev/null 1>/dev/null 2>&1 \
                        3<&- 4<&- 5<&- 6<&- 7<&- 8<&- 9<&- & 
				  CHKGNRC=$?
      
              # Save the MvWebService Process ID to a file
              echo $! > $pidfile
           fi
   
        sleep 10
       
		  checkPIDFile
        
        if [ "$CHKPIDRC" = 0 ] && [ "$CHKGNRC" = 0 ];
        then
	        if [ "$HPstrstp" = "1" ]; then
                   echo "MarkVision MvWebService started [`cat $pidfile`] as user [ `$WHOAMI` ]"
                   echo "on port [ $PORT ]."
                   echo
                fi
                exit 0;

        else
                   echo "Unable to start MvWebService."
                exit $CHKPIDRC;
        fi        
     fi
}

statusMvWebService()
{
        checkPIDFile
        if [ "$?" = "0" ]; then
           echo "MarkVision MvWebService is running at Process ID [${lastPID}] as user [ `$WHOAMI` ]"
           echo "on port [ $PORT ]."
        else
           echo "MarkVision MvWebService is not running."
        fi
        echo
        exit 0;
}


# Stops MvWebService using the Java Shutdown mechanism
stopMvWebService ()
{
        # Initialize Java vars for this script
        setJavaVars

        # See if MvWebService is running

	        if [ "$HPstrstp" = "1" ]; then
        echo "Shutting Down MvWebService"
                fi

        if [ ! -s $pidfile ];
        then

	   if [ "$HPstrstp" = "1" ]; then
           echo "MarkVision MvWebService not running. Missing or empty: $pidfile"
           fi
           exit 0
        else
           if [ "$DEBUG" = "1" ];
           then
               echo
               echo "Found $pidfile, trying to shutdown MvWebService  ...."
               echo "         Running the Following command"
               echo 
               echo "$StopCMD"
               echo
	   fi

        # Run the special MvWebService Shutdown program

        cd $TOMDIR
        $StopCMD </dev/null 1>/dev/null 2>&1
        StopReturn=$?
 
        # See if the shutdown worked
        if [ $StopReturn -eq 0 ];
        then

        if [ "$HPstrstp" = "1" ]; then
           echo "MarkVision MvWebService stopped [`cat $pidfile`]."
        fi

           # Remove PID file to indicate MvWebService is stopped
           rm -rf $pidfile 2>/dev/null 1>/dev/null
           exit 0;
           
      
        elif [ $? -eq 1 ];
        then
              
                echo "MarkVision MvWebService cannot stop itself [`cat $pidfile`]."
                killMvWebService

        elif [ $? -eq 2 ];
        then
                        
                echo "Failed to send shutdown command to MarkVision MvWebService [`cat $pidfile`]."
                killMvWebService
        fi

        
      fi
   
}

restartMvWebService()
{
        /usr/mv_pro/bin/MvWebService.sh stop
        /usr/mv_pro/bin/MvWebService.sh start
}

# kill MvWebService by SIGKILL
killMvWebService()
{

        #-- Make sure a process ID exists for MVJServer
		  checkPIDFile

		  #-- Kill the process if we're confident it's MvWebService 
        if [ "$CHKPIDRC" = "0" ]
        then
                
                echo "Killing MarkVision MvWebService, Process ID [${lastPID}] ..."
                kill -9 ${lastPID} 
                if [ "$?" = "0" ] 
                then
                  # Remove PID file to indicate MvWebService is stopped
                  rm -rf $pidfile 2>/dev/null 1>/dev/null
                  echo "MarkVision MvWebService process killed successfully."
                  exit 0
                else
                  echo "Kill failed - process must not be running. Removing PID file."
                  rm -rf $pidfile 2>/dev/null 1>/dev/null
                  exit 1
                fi
        else
                echo "MarkVision MvWebService is not running."
                exit 1
        fi
}

checkSpoolDir()
{
 
  # Create the markvision spool directory if it does not exist
  spoolDir="/var/spool/markvision"

  if [ "$DEBUG" = "1" ];
  then
     echo "   Checking to ensure there is a MV Spool Directory"
  fi

  if [ ! -d ${spoolDir} ] 
  then
    /bin/mkdir -p ${spoolDir}
    if [ $? -ne 0 ];
    then
       echo "/bin/mkdir -p ${spoolDir}: FAILED"
       exit 1
    else
       echo "   Created ${spoolDir}."
    fi
  else
    if [ "$DEBUG" = "1" ]; then
       echo "   Found MarkVision spool directory [ ${spoolDir} ] ... Good."
    fi
  fi
}

# Make sure that markvision spool directory exists
checkSpoolDir

# Determine whether to start or stop MvWebService
case "$RunMvWebService" in 
'start' )
        startMvWebService
        ;;
'restart' )
        restartMvWebService
        ;;
'stop')
        stopMvWebService
        ;;
'kill')
        killMvWebService
        ;;
'status')
        statusMvWebService
        ;;
*)
        echo
        echo "Usage: MvWebService { start|stop|restart|status }"
        echo
        exit 0;

        ;;
esac

exit 0
